@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
- *   dantti12@gmail.com                                                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; see the file COPYING. If not, write to       *
- *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010-2012 Daniel Nicoletti <dantti12@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "KCupsPasswordDialog.h"
 
@@ -26,6 +12,9 @@
 
 #include <KPasswordDialog>
 #include <KWindowSystem>
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+#include <KX11Extras>
+#endif
 #include <KLocalizedString>
 
 KCupsPasswordDialog::KCupsPasswordDialog(QObject *parent) :
@@ -63,7 +52,11 @@ void KCupsPasswordDialog::exec(const QString &username, bool wrongPassword)
         dialog->setAttribute(Qt::WA_NativeWindow, true);
         KWindowSystem::setMainWindow(dialog->windowHandle(), m_mainwindow);
     }
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    KX11Extras::forceActiveWindow(dialog->winId());
+#else
     KWindowSystem::forceActiveWindow(dialog->winId());
+#endif
 
     // Do not return from this method now
     dialog->exec();
